@import "base";

@primary: #409eff !important;
@color: white;

@menu-color: #696969 !important;
@menu-background: #ffffff !important;

@menu-color-hover: #696969;
@menu-background-hover: #fff;

@menu-title-color: #696969;
@menu-title-background-color: #fff;

@menu-title-color-hover: #666;
@menu-title-background-color-hover: #f2f3f7;


@navbar-color: #FFF;
@navbar-background: #447eff;

.menu {
  .el-menu .is-active {
    color: @primary;
    background-color: @menu-title-background-color-hover !important;
  }
}