{% load i18n static %}
<html>
<head><title>{% trans 'Popup closing...' %}</title></head>
<body>
<script type="text/javascript"
        id="django-admin-popup-response-constants"
        src="{% static 'admin/js/popup_response.js' %}"
        data-popup-response="{{ popup_response_data }}">
</script>
</body>
</html>
