(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/si', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.si = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'හරි',
        clear: 'හිස් කරන්න'
      },
      datepicker: {
        now: 'දැන්',
        today: 'අද',
        cancel: 'අවලංගු කරන්න',
        clear: 'හිස් කරන්න',
        confirm: 'හරි',
        selectDate: 'දිනය තෝරන්න',
        selectTime: 'වේලාව තෝරන්න',
        startDate: 'ආරම්භක දිනය',
        startTime: 'ආරම්භක වේලාව',
        endDate: 'අවසන් වන දිනය',
        endTime: 'අවසන් වන වේලාව',
        prevYear: 'කලින් අවුරුද්ද',
        nextYear: 'ඊළඟ අවුරුද්ද',
        prevMonth: 'කලින් මාසය',
        nextMonth: 'ඊළඟ මාසය',
        year: '',
        month1: 'දුරුතු',
        month2: 'නවම්',
        month3: 'මැදින්',
        month4: 'බක්',
        month5: 'වෙසක්',
        month6: 'පොසොන්',
        month7: 'ඇසළ',
        month8: 'නිකිණි',
        month9: 'බිනර',
        month10: 'වප්',
        month11: 'ඉල්',
        month12: 'උඳුවප්',
        week: 'සතිය',
        weeks: {
          sun: 'ඉරිදා',
          mon: 'සඳුදා',
          tue: 'අඟහ',
          wed: 'බදාදා',
          thu: 'බ්‍රහස්',
          fri: 'සිකු',
          sat: 'සෙන'
        },
        months: {
          jan: 'දුරුතු',
          feb: 'නවම්',
          mar: 'මැදින්',
          apr: 'බක්',
          may: 'වෙසක්',
          jun: 'පොසොන්',
          jul: 'ඇසළ',
          aug: 'නිකිණි',
          sep: 'බිනර',
          oct: 'වප්',
          nov: 'ඉල්',
          dec: 'උඳුව'
        }
      },
      select: {
        loading: 'පූරණය වෙමින්',
        noMatch: 'ගැළපෙන දත්ත නැත',
        noData: 'දත්ත නැත',
        placeholder: 'තෝරන්න'
      },
      cascader: {
        noMatch: 'ගැළපෙන දත්ත නැත',
        loading: 'පූරණය වෙමින්',
        placeholder: 'තෝරන්න',
        noData: 'දත්ත නැත'
      },
      pagination: {
        goto: 'වෙත යන්න',
        pagesize: '/පිටුව',
        total: 'මුළු {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'පණිවිඩය',
        confirm: 'හරි',
        cancel: 'අවලංගු කරන්න',
        error: 'අනීතික ආදානයකි'
      },
      upload: {
        deleteTip: 'ඉවතලීමට මකන්න ඔබන්න',
        delete: 'මකන්න',
        preview: 'පෙරදසුන',
        continue: 'ඉදිරියට'
      },
      table: {
        emptyText: 'දත්ත නැත',
        confirmFilter: 'තහවුරු',
        resetFilter: 'යළි සකසන්න',
        clearFilter: 'සියල්ල',
        sumText: 'එකතුව'
      },
      tree: {
        emptyText: 'දත්ත නැත'
      },
      transfer: {
        noMatch: 'ගැළපෙන දත්ත නැත',
        noData: 'තෝරන්න',
        titles: ['ලේඛනය 1', 'ලේඛනය 2'], // to be translated
        filterPlaceholder: 'මූලපදය යොදන්න', // to be translated
        noCheckedFormat: 'අථක {total}', // to be translated
        hasCheckedFormat: '{checked}/{total} පරීක්‍ෂා විය' // to be translated
      },
      image: {
        error: 'අසමත් විය'
      },
      pageHeader: {
        title: 'ආපසු' // to be translated
      },
      popconfirm: {
        confirmButtonText: 'ඔව්',
        cancelButtonText: 'නැහැ'
      },
      empty: {
        description: 'දත්ත නැත'
      }
    }
  };
  module.exports = exports['default'];
});