(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/sr', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.sr = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'OK',
        clear: 'Поништи'
      },
      datepicker: {
        now: 'Сад',
        today: 'Данас',
        cancel: 'Откажи',
        clear: 'Бриши',
        confirm: 'OK',
        selectDate: 'Изабери датум',
        selectTime: 'Изабери време',
        startDate: 'Датум почетка',
        startTime: 'Време почетка',
        endDate: 'Датум завршетка',
        endTime: 'Време завршетка',
        prevYear: 'Претходна година',
        nextYear: 'Следећа година',
        prevMonth: 'Претходни месец',
        nextMonth: 'Следећи месец',
        year: 'година',
        month1: 'јануар',
        month2: 'фебруар',
        month3: 'март',
        month4: 'април',
        month5: 'мај',
        month6: 'јун',
        month7: 'јул',
        month8: 'август',
        month9: 'септембар',
        month10: 'октобар',
        month11: 'новембар',
        month12: 'децембар',
        week: 'седмица',
        weeks: {
          sun: 'Нед',
          mon: 'Пон',
          tue: 'Уто',
          wed: 'Сре',
          thu: 'Чет',
          fri: 'Пет',
          sat: 'Суб'
        },
        months: {
          jan: 'јан',
          feb: 'феб',
          mar: 'мар',
          apr: 'апр',
          may: 'мај',
          jun: 'јун',
          jul: 'јул',
          aug: 'авг',
          sep: 'сеп',
          oct: 'окт',
          nov: 'нов',
          dec: 'дец'
        }
      },
      select: {
        loading: 'Учитавање',
        noMatch: 'Нема резултата',
        noData: 'Нема података',
        placeholder: 'Изабери'
      },
      cascader: {
        noMatch: 'Нема резултата',
        loading: 'Учитавање',
        placeholder: 'Изабери',
        noData: 'Нема података'
      },
      pagination: {
        goto: 'Иди на',
        pagesize: '/страни',
        total: 'Укупно {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'Порука',
        confirm: 'OK',
        cancel: 'Откажи',
        error: 'Неисправан унос'
      },
      upload: {
        deleteTip: 'притисни БРИШИ да обришеш',
        delete: 'Бриши',
        preview: 'Види',
        continue: 'Настави'
      },
      table: {
        emptyText: 'Нема података',
        confirmFilter: 'Потврди',
        resetFilter: 'Ресетуј',
        clearFilter: 'Све',
        sumText: 'Збир'
      },
      tree: {
        emptyText: 'Нема података'
      },
      transfer: {
        noMatch: 'Нема резултата',
        noData: 'Нема података',
        titles: ['Листа 1', 'Листа 2'], // to be translated
        filterPlaceholder: 'Унеси кључну реч', // to be translated
        noCheckedFormat: '{total} ставки', // to be translated
        hasCheckedFormat: '{checked}/{total} обележених' // to be translated
      },
      image: {
        error: 'FAILED' // to be translated
      },
      pageHeader: {
        title: 'Back' // to be translated
      },
      popconfirm: {
        confirmButtonText: 'Yes', // to be translated
        cancelButtonText: 'No' // to be translated
      },
      empty: {
        description: 'Нема података'
      }
    }
  };
  module.exports = exports['default'];
});