{% load static simpletags %}
<link rel="stylesheet" type="text/css" href="{% static 'admin/simpleui-x/elementui/theme-chalk/index.css' %}">
<link rel="stylesheet" type="text/css" href="{% static 'admin/simpleui-x/fontawesome-free-6.2.0-web/css/all.min.css' %}">